@@ -58,7 +58,7 @@ from repo_helper_github.options import token_option, version_callback
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.2.1"
+__version__: str = "0.2.3"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
@@ -95,6 +95,10 @@ def echo_rate_limit(github: Github, verbose: bool = True):
 		click.echo(f"Used {used_requests} requests. {rate.core.remaining} remaining. Resets at {rate.core.reset}")
 
 
+def _lower(string: str) -> str:
+	return string.lower()
+
+
 class GithubManager(RepoHelper):
 	"""
 	Subclass of :class:`repo_helper.core.RepoHelper`
@@ -106,7 +110,7 @@ class GithubManager(RepoHelper):
 	:param verbose: Whether to show information on the GitHub API rate limit.
 	:param colour: Whether to use coloured output.
 
-	.. versionchanged:: 0.2.1
+	.. versionchanged:: 0.2.3
 
 		Added the ``verbose`` and ``colour`` options.
 	"""
@@ -118,14 +122,14 @@ class GithubManager(RepoHelper):
 	"""
 	Whether to show information on the GitHub API rate limit.
 
-	.. versionadded: 0.2.1
+	.. versionadded: 0.2.3
 	"""
 
 	colour: Optional[bool]
 	"""
 	Whether to use coloured output.
 
-	.. versionadded: 0.2.1
+	.. versionadded: 0.2.3
 	"""
 
 	def __init__(
@@ -150,7 +154,7 @@ class GithubManager(RepoHelper):
 		"""
 		Create a new GitHub repository for this project.
 
-		.. versionchanged:: 0.2.1
+		.. versionchanged:: 0.2.3
 
 			Removed the ``verbose`` option. Provide it to the class constructor instead.
 		"""
@@ -185,7 +189,7 @@ class GithubManager(RepoHelper):
 		"""
 		Update the GitHub repository for this project.
 
-		.. versionchanged:: 0.2.1
+		.. versionchanged:: 0.2.3
 
 			Removed the ``verbose`` option. Provide it to the class constructor instead.
 		"""
@@ -209,7 +213,7 @@ class GithubManager(RepoHelper):
 		"""
 		Set or update the secrets of the GitHub repository for this project.
 
-		.. versionadded: 0.2.1
+		.. versionadded: 0.2.3
 		"""
 
 		with self.echo_rate_limit():
@@ -235,8 +239,12 @@ class GithubManager(RepoHelper):
 			public_key = (secrets_url / "public-key").get().json()
 
 			ret = 0
+			target_secrets = {"PYPI_TOKEN"}
 
-			for secret_name in ("ANACONDA_TOKEN", "PYPI_TOKEN"):
+			if self.templates.globals["enable_conda"]:
+				target_secrets.add("ANACONDA_TOKEN")
+
+			for secret_name in sorted(target_secrets):
 				if secret_name in existing_secrets:
 					click.echo(f"A value for the secret {secret_name!r} already exists. ")
 					update = confirm("Do you want to update the secret?")
@@ -289,7 +297,7 @@ class GithubManager(RepoHelper):
 		topics = set(repo.get_topics())
 		topics.add("python")
 		topics.update(self.templates.globals["keywords"])
-		repo.replace_topics(sorted(topics))
+		repo.replace_topics(sorted(map(_lower, topics)))
 
 	@staticmethod
 	def handle_exception(exc: GithubException) -> NoReturn:
@@ -313,7 +321,7 @@ class GithubManager(RepoHelper):
 		edit_kwargs: _EditKwargs = {"description": self.templates.globals["short_desc"]}
 
 		if self.templates.globals["enable_docs"]:
-			edit_kwargs["homepage"] = "https://{repo_name}.readthedocs.io".format_map(self.templates.globals)
+			edit_kwargs["homepage"] = self.templates.globals["docs_url"]
 
 		return edit_kwargs
 
@@ -325,7 +333,7 @@ def encrypt_secret(public_key: str, secret_value: str) -> str:
 	:param public_key:
 	:param secret_value:
 
-	.. versionadded: 0.2.1
+	.. versionadded: 0.2.3
 	"""
 
 	public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
